==> xnu-1504.15.3.tar.gz: xnu-xnu-1504.15.3/osfmk/kern/audit_sessionport.h <==
/*
 * Copyright (c) 2008 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifdef KERNEL_PRIVATE
#ifndef _KERN_AUDIT_SESSIONPORT_H_
#define _KERN_AUDIT_SESSIONPORT_H_

struct auditinfo_addr;

ipc_port_t audit_session_mksend(struct auditinfo_addr *aia_p,
    ipc_port_t *sessionport);
struct auditinfo_addr *audit_session_porttoaia(ipc_port_t);
void audit_session_portaiadestroy(struct auditinfo_addr *);
void audit_session_nosenders(mach_msg_header_t *);

#endif /* _KERN_AUDIT_SESSIONPORT_H_ */
#endif /* KERNEL_PRIVATE */

==> xnu-10002.1.13.tar.gz: xnu-xnu-10002.1.13/osfmk/kern/audit_sessionport.h <==
/*
 * Copyright (c) 2008 Apple Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 *
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 *
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 *
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */
#ifdef KERNEL_PRIVATE
#ifndef _KERN_AUDIT_SESSIONPORT_H_
#define _KERN_AUDIT_SESSIONPORT_H_

struct auditinfo_addr;

ipc_port_t audit_session_mksend(struct auditinfo_addr *, ipc_port_t *);
struct auditinfo_addr *audit_session_porttoaia(ipc_port_t);
void audit_session_portdestroy(ipc_port_t *);
void audit_session_aiaref(struct auditinfo_addr *);
void audit_session_aiaunref(struct auditinfo_addr *);

#endif /* _KERN_AUDIT_SESSIONPORT_H_ */
#endif /* KERNEL_PRIVATE */
